sqlobject.tests.test_create_drop module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_create_drop module

class `sqlobject.tests.test_create_drop.` `SOTestCreateDrop`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `blobcol`
  `j` = test_create_drop_table
  property `name`
  property `number`
  `q` = test_create_drop_table
  property `short`
  property `so_time`
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'test_id_here'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_create_drop.SOTestCreateDrop`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'test_create_drop_table'

`sqlobject.tests.test_create_drop.` `test_create_drop`()